aboutsummaryrefslogtreecommitdiffstats
path: root/meta-xfce/recipes-xfce/xfce4-panel/files/0001-use-lxdm-to-replace-dm-tool.patch
blob: b06e26e91d77b6272e5ac8567e3d090c58357c48 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
From b80108f01b1425427f98341168ea44c4b1a5a2cf Mon Sep 17 00:00:00 2001
From: Hongxu Jia <hongxu.jia@windriver.com>
Date: Fri, 28 Jun 2019 16:02:13 +0800
Subject: [PATCH] use lxdm to replace dm-tool

OE does not support lightdm but lxdm,
so use lxdm to replace dm-tool

Upstream-Status: Inappropriate [oe specific]

Signed-off-by: Hongxu Jia <hongxu.jia@windriver.com>
---
 plugins/actions/actions.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/plugins/actions/actions.c b/plugins/actions/actions.c
index 474798e..63eb41d 100644
--- a/plugins/actions/actions.c
+++ b/plugins/actions/actions.c
@@ -905,12 +905,12 @@ actions_plugin_actions_allowed (void)
   GError          *error = NULL;
 
   /* check for commands we use */
-  path = g_find_program_in_path ("dm-tool");
+  path = g_find_program_in_path ("lxdm");
   if (path != NULL)
     PANEL_SET_FLAG (allow_mask, ACTION_TYPE_SWITCH_USER);
   else
   {
     /* check for gdmflexiserver if dm-tool is not present */
     g_free (path);
     path = g_find_program_in_path ("gdmflexiserver");
     if (path != NULL)
@@ -1027,9 +1027,9 @@ actions_plugin_action_activate (GtkWidget      *widget,
       break;
 
     case ACTION_TYPE_SWITCH_USER:
-      path = g_find_program_in_path ("dm-tool");
+      path = g_find_program_in_path ("lxdm");
       if (path != NULL)
-        succeed = g_spawn_command_line_async ("dm-tool switch-to-greeter", &error);
+        succeed = g_spawn_command_line_async ("lxdm -c USER_SWITCH", &error);
       else
         succeed = g_spawn_command_line_async ("gdmflexiserver", &error);
       g_free (path);
@@ -905,12 +905,12 @@ actions_plugin_actions_allowed (void)
   else
   {
-    /* check for gdmflexiserver if dm-tool is not present */
+    /* check for gdmflexiserver if lxdm is not present */
     g_free (path);
     path = g_find_program_in_path ("gdmflexiserver");
-- 
2.8.1